==> openejb-jee-4.6.0-sources.jar: org/apache/openejb/jee/jba/cmp/LoadGroup.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.jee.jba.cmp;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://jboss.org}description" minOccurs="0"/>
 *         &lt;element ref="{http://jboss.org}load-group-name"/>
 *         &lt;element ref="{http://jboss.org}field-name" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "description",
    "loadGroupName",
    "fieldName"
})
@XmlRootElement(name = "load-group")
public class LoadGroup {

    protected Description description;
    @XmlElement(name = "load-group-name", required = true)
    protected LoadGroupName loadGroupName;
    @XmlElement(name = "field-name", required = true)
    protected List<FieldName> fieldName;

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link Description }
     *     
     */
    public Description getDescription() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link Description }
     *     
     */
    public void setDescription(Description value) {
        this.description = value;
    }

    /**
     * Gets the value of the loadGroupName property.
     * 
     * @return
     *     possible object is
     *     {@link LoadGroupName }
     *     
     */
    public LoadGroupName getLoadGroupName() {
        return loadGroupName;
    }

    /**
     * Sets the value of the loadGroupName property.
     * 
     * @param value
     *     allowed object is
     *     {@link LoadGroupName }
     *     
     */
    public void setLoadGroupName(LoadGroupName value) {
        this.loadGroupName = value;
    }

    /**
     * Gets the value of the fieldName property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the fieldName property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFieldName().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link FieldName }
     * 
     * 
     */
    public List<FieldName> getFieldName() {
        if (fieldName == null) {
            fieldName = new ArrayList<FieldName>();
        }
        return this.fieldName;
    }

}

==> openejb-jee-4.7.1-sources.jar: org/apache/openejb/jee/jba/cmp/LoadGroup.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.openejb.jee.jba.cmp;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import java.util.ArrayList;
import java.util.List;


/**
 * <p>Java class for anonymous complex type.
 * <p/>
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p/>
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://jboss.org}description" minOccurs="0"/>
 *         &lt;element ref="{http://jboss.org}load-group-name"/>
 *         &lt;element ref="{http://jboss.org}field-name" maxOccurs="unbounded"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "description",
    "loadGroupName",
    "fieldName"
})
@XmlRootElement(name = "load-group")
public class LoadGroup {

    protected Description description;
    @XmlElement(name = "load-group-name", required = true)
    protected LoadGroupName loadGroupName;
    @XmlElement(name = "field-name", required = true)
    protected List<FieldName> fieldName;

    /**
     * Gets the value of the description property.
     *
     * @return possible object is
     * {@link Description }
     */
    public Description getDescription() {
        return description;
    }

    /**
     * Sets the value of the description property.
     *
     * @param value allowed object is
     *              {@link Description }
     */
    public void setDescription(final Description value) {
        this.description = value;
    }

    /**
     * Gets the value of the loadGroupName property.
     *
     * @return possible object is
     * {@link LoadGroupName }
     */
    public LoadGroupName getLoadGroupName() {
        return loadGroupName;
    }

    /**
     * Sets the value of the loadGroupName property.
     *
     * @param value allowed object is
     *              {@link LoadGroupName }
     */
    public void setLoadGroupName(final LoadGroupName value) {
        this.loadGroupName = value;
    }

    /**
     * Gets the value of the fieldName property.
     * <p/>
     * <p/>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the fieldName property.
     * <p/>
     * <p/>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFieldName().add(newItem);
     * </pre>
     * <p/>
     * <p/>
     * <p/>
     * Objects of the following type(s) are allowed in the list
     * {@link FieldName }
     */
    public List<FieldName> getFieldName() {
        if (fieldName == null) {
            fieldName = new ArrayList<FieldName>();
        }
        return this.fieldName;
    }

}
